﻿// a sorok tördelése a 24 pontos Courier New betűtípushoz optimalizálva
// a projektoros kivetítéshez

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO;

namespace Foci
{
    class erettsegi07_Foci
    {
        struct Meccs
        {
            public string Hazai;
            public string Idegen;
            public int FélidőHazai;
            public int FélidőIdegen;
            public int EredményHazai;
            public int EredményIdegen;
            public byte Forduló;
            public string Győztes { get { return EredményHazai > EredményIdegen ? 
            Hazai : EredményHazai == EredményIdegen ? "Döntetlen" : Idegen; } }
            public string EredményString { get 
            { return Math.Max(EredményHazai, EredményIdegen).ToString() + '-' +
                     Math.Min(EredményHazai, EredményIdegen).ToString(); } }
        }

        static void Main()
        {
            #region 1. Feladat: Adatok beolvasása a meccs.txt-ből
            List<Meccs> meccsek = new List<Meccs>();
            using (StreamReader sr = new StreamReader("meccs.txt"))
            {
                int db=int.Parse(sr.ReadLine());
                for (int i = 0; i < db; i++)
                {
                    string sor= sr.ReadLine();
                    string[] fields = sor.Trim().Split(' ');
                    Meccs újMeccs = new Meccs()
                    {
                        Forduló = byte.Parse(fields[0]),
                        EredményHazai = int.Parse(fields[1]),
                        EredményIdegen = int.Parse(fields[2]),
                        FélidőHazai = int.Parse(fields[3]),
                        FélidőIdegen= int.Parse(fields[4]),
                        Hazai = fields[5],
                        Idegen = fields[6]
                    };
                    meccsek.Add(újMeccs);
                }
            }
            #endregion

            #region 2. Feladat: Bekért forduló eredményei
            Console.WriteLine("\n2. feladat: Bekért forduló eredményei");
            Console.Write("Forduló száma: ");
            byte forduló = byte.Parse(Console.ReadLine());

            //Linq használatával:
            var fordulók = from m in meccsek
                           where m.Forduló == forduló
                           select m;

            //a "fordulók" változó az átláthatóság végett készült
            foreach (var i in fordulók) 
                Console.WriteLine("{0}-{1}: {2}-{3} ({4}-{5})", 
                    i.Hazai.PadRight(20,' '), i.Idegen.PadRight(20,' '),
                    i.EredményHazai, i.EredményIdegen, i.FélidőHazai,
                    i.FélidőIdegen);
            #endregion

            #region 3. Feladat: Eredményt megfordító csapatok a félidőhöz képest
            Console.WriteLine("\n3. Feladat: Az eredményt megfordító csapatok:");
            var fordítások = from m in meccsek
                             where ( (m.EredményHazai > m.EredményIdegen &&
                                      m.FélidőHazai < m.FélidőIdegen) ||
                                     (m.EredményHazai < m.EredményIdegen && 
                                      m.FélidőHazai > m.FélidőIdegen))
                             select m;

            foreach (var i in fordítások)
                Console.WriteLine("{0}. forduló: {1}", i.Forduló, i.Győztes);
            #endregion

            #region 4. Feladat: Kiválasztott csapat bekérése
            Console.WriteLine("\n4. feladat: Kiválasztott csapat bekérése");
            Console.Write("A kiválasztott csapat neve: ");
            string kcs= Console.ReadLine();
            #endregion

            #region 5. Feladat: Lőtt és kapott gólok száma
            Console.WriteLine("\n5. Feladat: Lőtt és kapott gólok száma ({0})",kcs);
            var hazaiLőtt = (from m in meccsek
                             where m.Hazai == kcs
                             select m.EredményHazai).Sum();

            var idegenLőtt = (from m in meccsek
                              where m.Idegen == kcs
                              select m.EredményIdegen).Sum();

            var hazaiKapott = (from m in meccsek
                               where m.Hazai == kcs
                               select m.EredményIdegen).Sum();

            var idegenKapott = (from m in meccsek
                                where m.Idegen == kcs
                                select m.EredményHazai).Sum();

            Console.WriteLine("lőtt: {0} kapott: {1}", hazaiLőtt + idegenLőtt,
                               hazaiKapott + idegenKapott);
            #endregion

            #region 6. Feladat: Mikor és kitől kapott ki otthon?
            Console.WriteLine("\n6. Mikor és kitől kapott ki otthon először?");
            var elsőKikap = (from m in meccsek 
                             where m.Hazai == kcs && m.Győztes != kcs && 
                                               m.Győztes != "Döntetlen" 
                             orderby m.Forduló
                             select m);

            if (elsőKikap.Count() > 0)
                Console.WriteLine(
                "A(z){0} a(z) {1}. f.-ban kapott ki először a(z) {2}-tól/től!",
                kcs, elsőKikap.First().Forduló, elsőKikap.First().Győztes);
                else Console.WriteLine("A csapat otthon veretlen maradt.");
            #endregion

            #region 7. Feladat: Satisztika
            Console.WriteLine("\n7. Feladat: Statisztika");
            Dictionary<string, byte> azonosak = new Dictionary<string, byte>();

            var stathoz = from m in meccsek
                          select m.EredményString;

            foreach (var i in stathoz)
            {
                if (azonosak.ContainsKey(i)) azonosak[i]++;
                else azonosak.Add(i, 1);
            }
            using (StreamWriter sw = new StreamWriter("stat.txt"))
            {
                foreach (var i in azonosak)
                {
                    sw.WriteLine("{0}: {1} darab", i.Key, i.Value);
                    Console.WriteLine("{0}: {1} darab", i.Key, i.Value);
                }
            }
            #endregion

            Console.ReadKey();
        }
    }

}